# xml2abc

**Author:** Willem (Wim) Vree  
**Source:** https://wim.vree.org/js/xml2abc-js_index.html  
**License:** LGPL (see file header)

`xml2abc.py` converts MusicXML to ABC notation. It is included here unmodified
and is the sole LGPL-licensed component in abcforge.

This file may be replaced or modified independently of the rest of the package.
